@@ -1,6 +1,7 @@
 package Config::App;
 # ABSTRACT: Cascading merged application configuration
 
+use 5.008;
 use strict;
 use warnings;
 
@@ -12,7 +13,7 @@ use JSON::XS ();
 use YAML::XS ();
 use POSIX ();
 
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 $Carp::Internal{ (__PACKAGE__) }++;
 
@@ -60,6 +61,13 @@ sub import {
         $self = bless( { _conf => $conf }, $self );
         $singleton = $self unless ($no_singleton);
 
+        if ( my $libs = $self->get('libs') ) {
+            $libs        = [$libs] if ( ref $libs ne 'ARRAY' );
+            my $root_dir = $self->get( qw( config_app root_dir ) );
+
+            unshift( @INC, $root_dir . "/$_" ) for (@$libs);
+        }
+
         return $self;
     }
 }
@@ -136,10 +144,6 @@ sub _location_fetch {
         _location_fetch( $box, $user, $env, $conf, \$optional_include, $location, @source_path );
     }
 
-    if ( $conf->{libs} and ref $conf->{libs} eq 'ARRAY' ) {
-        unshift( @INC, $root_dir . "/$_" ) for ( @{ $conf->{libs} } );
-    }
-
     return;
 }
 
@@ -296,7 +300,7 @@ Config::App - Cascading merged application configuration
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Config-App.svg)](https://travis-ci.org/gryphonshafer/Config-App)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Config-App/badge.png)](https://coveralls.io/r/gryphonshafer/Config-App)
@@ -581,9 +585,10 @@ To skip all this behavior, do this:
 
 =head2 Injection via configuration file setting
 
-You can also inject relative library paths by using the "libs" keyword in the
-base of the configuration, similar to "include". The "libs" keyword expects an
-arrayref of relative paths.
+You can also inject a relative library path or set of paths by using the "libs"
+keyword in the configuration file. The "libs" keyword should have either an
+arrayref of relative paths or a string of a single relative path, relative to
+the project's root directory.
 
 =head1 DIRECT DEPENDENCIES
 
@@ -635,7 +640,7 @@ Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Gryphon Shafer.
+This software is copyright (c) 2018 by Gryphon Shafer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
